@@ -140,7 +140,7 @@ class JSONAPIResponse(object):
         self.status_code = 200
         self.data = {
             'jsonapi': {'version': '1.0'},
-            'meta': {'sqlalchemy_jsonapi_version': '4.0.6'}
+            'meta': {'sqlalchemy_jsonapi_version': '4.0.8'}
         }
 
 
@@ -884,7 +884,7 @@ class JSONAPI(object):
         json_data['data'].setdefault('relationships', {})
         json_data['data'].setdefault('attributes', {})
 
-        data_keys = set(json_data['data']['relationships'].keys())
+        data_keys = set(map((lambda x: resource.__jsonapi_map_to_py__.get(x, None)), json_data['data'].get('relationships', {}).keys()))
         model_keys = set(resource.__mapper__.relationships.keys())
         if not data_keys <= model_keys:
             raise BadRequestError(
